#
# spec file for package etherape
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           etherape
Version:        0.9.20
Release:        4.3
Summary:        A Graphical Network Monitor
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Diagnostic
URL:            https://etherape.sourceforge.io/
Source0:        https://prdownloads.sourceforge.net/etherape/%{name}-%{version}.tar.gz
Patch0:         etherape-0.9.12-desktop.patch
BuildRequires:  docbook_4
BuildRequires:  fdupes
BuildRequires:  libpcap-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(goocanvas-2.0)
BuildRequires:  pkgconfig(popt)
Requires(post): update-desktop-files
Requires(postun):update-desktop-files
Requires:       xdg-utils
Recommends:     %{name}-lang
%if 0%{?is_opensuse}
BuildRequires:  autoconf-archive
%endif

%description
EtherApe is a graphical network monitor for Unix, modeled after
etherman. Featuring link layer, IP, and TCP modes, it displays network
activity graphically. Hosts and links change in size with traffic.
Various protocols are color coded in the display. It supports ethernet,
FDDI, token ring, ISDN, PPP, and SLIP devices. It can filter traffic to
show and can read traffic from a file as well as live from the network.

%lang_package

%prep
%autosetup -p1

%build
%configure
%make_build

%check
%make_build check

%install
%make_install

# desktop file
# additional root desktop file
cp %{name}.desktop %{buildroot}%{_datadir}/applications/%{name}-su.desktop
sed -i -e 's|Name=EtherApe|Name=EtherApe - Super User Mode|g' %{buildroot}%{_datadir}/applications/%{name}-su.desktop
sed -i -e 's|Exec=etherape|Exec=xdg-su -c etherape|g' %{buildroot}%{_datadir}/applications/%{name}-su.desktop
%suse_update_desktop_file %{name} System Network
%suse_update_desktop_file %{name}-su System Network

%find_lang %{name}
%fdupes -s %{buildroot}

%if 0%{?suse_version} < 1500
%post
%desktop_database_post

%postun
%desktop_database_postun
%endif

%files
%license COPYING
%doc TODO NEWS README* AUTHORS ABOUT-NLS
%{_bindir}/etherape
%{_datadir}/applications/etherape.desktop
%{_datadir}/applications/etherape-su.desktop
%{_datadir}/etherape
%{_mandir}/man1/etherape.1%{?ext_man}
%{_datadir}/pixmaps/etherape.png

%files lang -f %{name}.lang

%changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Fri Dec  2 2022 ecsos <ecsos@opensuse.org>
- Add additional desktopfile for root.
* Thu Apr 28 2022 Dirk Müller <dmueller@suse.com>
- fix homepage url
- spec-cleaner
* Wed Jan 26 2022 Wolfgang Frisch <wolfgang.frisch@suse.com>
- Update to version 0.9.20:
  - fix for ticket #100, thanks to Salam for reporting it.
  - diagram refresh command, thanks to Ronald W. Henderson
  - patch to remove artifact when resizing, thanks to Ronald W. Henderson
  - reorder keyboard shortcuts, thanks to Ronald W. Henderson
  - sort by port on protocol windows, thanks to Ronald W. Henderson
  - xml output now containes also link and global protocols statistics.
  - link fades with averaging times
  - node-link ratio slider removed, ratio always fixed at 1 (links sizes
    are aligned with nodes)
  - improve statistics repeatability esp. when setting max-delay=0 (useful
    for tests or just to calculate quickly statistics of a dump file).
  - new no-display mode (command line only), disables diagram updates
    (again, mostly for testing).
  - merged link protocol and traffic timeouts.
* Tue Mar  2 2021 Marcus Meissner <meissner@suse.com>
- replaced goocanvas-devel by pkgconfig(goocanvas-2.0) to use the right
  goocanvas.
* Tue Jul 21 2020 Wolfgang Frisch <wolfgang.frisch@suse.com>
- Update to version 0.9.19.
  * Better sizing of connections lines.
  * Fix for UI crash by "MandatoryField".
  * Fix a crash happening when the capture process wasn't able to set the filter.
  * Russian translation and fixes.
* Mon Jul  1 2019 Wolfgang Frisch <wolfgang.frisch@suse.com>
- Update to version 0.9.18:
  * EtherApe now is a pure GTK 3 application.
- Changes from version 0.9.17:
  * Replaced gnome-canvas with canvas supplied by GooCanvas.
* Fri May 18 2018 bjorn.lie@gmail.com
- Update to version 0.9.17:
  * EtherApe now requires Gtk 2.24.
  * Fixed a bug making libglade load gnome2 libraries.
  * Sometimes node/links windows were freezing.
- Changes from version 0.9.16:
  * Require only gnome-canvas, not gnome-ui.
  * Migrate from deprecated gnome-doc-utils to yelp-tools.
  * Updated translations.
- Following upstream changes:
  * Drop scrollkeeper, pkgconfig(gnome-doc-utils) and
    pkgconfig(libgnomeui-2.0) BuildRequires.
  * Add yelp-tools, pkgconfig(glib-2.0), pkgconfig(popt) and
    pkgconfig(libgnomecanvas-2.0) BuildRequires.
  * Drop usage of sed to fix doc/C/etherape.xml, file no longer
    exists.
  * No longer pass --disable-scrollkeeper to configure, not needed.
- Rebase etherape-0.9.12-desktop.patch.
- Add conditional for desktop_database_post(un) post(un) handling,
  no longer needed on modern releases of openSUSE.
* Thu Mar 23 2017 jengelh@inai.de
- Remove --with-pic, this is only for static libs
  (and there are _none at all_).
* Sun Mar  5 2017 mpluskal@suse.com
- Update to version 0.9.15 (boo#1028009):
  * fixed incorrect WLAN control frames decoding
  * fix UTF-8 encoding of several files, thanks to StrPt.
  * read system services file instead of EtherApe one, thanks to
    Zev Weiss.
  * fix race condition on exit, thanks to Zev Weiss
  * central ring option, thanks to Zev Weiss
  * tweaks to preference windows to better work with tiling
    managers, thanks to Zev Weiss.
  * static background image (Glenn Feunteun)
  * arrange nodes in 'columns' (David Goldfarb)
- Changes for version 0.9.14:
  * fixed incorrect WLAN control frames decoding
  * fix UTF-8 encoding of several files, thanks to StrPt.
  * read system services file instead of EtherApe one, thanks to
    Zev Weiss.
  * fix race condition on exit, thanks to Zev Weiss
  * central ring option, thanks to Zev Weiss
  * tweaks to preference windows to better work with tiling
    managers, thanks to Zev Weiss.
  * static background image (Glenn Feunteun)
  * arrange nodes in 'columns' (David Goldfarb)
- Packaging changes:
  * Run spec-cleaner
  * Add desktop file scriplets and corresponding dependencies
  * Split lang subpackage
* Thu Dec 26 2013 dimstar@opensuse.org
- Own %%{_datadir}/omf: we don't want to rely on scrollkeeper (or
  rarian-scrollkeeper-compat) being installed and owning the
  directory. And as such, we have to declare ownership (so that it
  gets correctly removed on uninstall, if nothing relies on it
  anymore).
* Wed Dec 18 2013 meissner@suse.com
- updated to 0.9.13
  Central node option, useful for displaying routers or proxies.
  Translations and documentation updates, plus some fixes.
  Changes summary:
  * Optional central node, based on work of Javier Fernandez-Sanguino Peña.
  * re-enabled full-screen mode, thanks to nrvale0
  * Updated spanish translation, thanks to Javier Fernandez-Sanguino Peña.
  * Added German translation, and fixed typos, thanks to Chris Leick.
  * Updated documentation.
* Sun Sep 29 2013 zaitor@opensuse.org
- Add scrollkeeper BuildRequires, needed now due to changes made in
  gnome-doc-utils-devel.
* Mon Sep 19 2011 meissner@suse.de
- updated to 0.9.12
  * fixed a RPC remote denial of service
- updated to 0.9.11
  * EtherApe now can save a snapshot with all known nodes and relevant
    informations to an XML file. With option --final-export, a dump is
    automatically generated when a capture file is fully replayed.
    Additionally, option --signal-export enables SIGUSR1 handling, to
    dump on signal.
  * EtherApe used to have two links for connection, one for each traffic
    direction. With this release, only one link is needed, gaining more
    complete statistics and better resource usage.
  * EtherApe config file is now ~/.config/etherape, instead of the older,
    deprecated, ~/.gnome2/Etherape. Migration is automatic.
    Filter expression is now saved.
  * The old, deprecated, direct resolver was removed. Name resolution is now
    only done with the full fledged threaded resolver.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
* Tue Feb  8 2011 meissner@suse.de
- removed unnecessary patch
* Mon Feb  7 2011 meissner@suse.de
- updated to 0.9.10
  * IPV6 support, thanks to David Flamand.
  * new statistic: average packet size.
  * added option --min-delay, to complement --max-delay when
    replaying from file. With this option you can replay a capture
    in slow-motion.
  * tweaked default service file, adding some common ports.
  * added check for invalid proto-color mappings (debian bug 566226).
  * removed bogus double assignement. Thanks to "johndoe123321".
* Fri Jan 14 2011 malcolmlewis@opensuse.org
- Fix spec file trailing \ to enable building
* Tue Jan  4 2011 malcolmlewis@opensuse.org
- Update desktop patch
- Add optflags to fix gcc warning
- Disable scrollkeeper
- Spec file tidy up
* Sun Feb 28 2010 bitshuffler@opensuse.org
- updated to 0.9.9
- enabled parallel building
* Mon Nov 16 2009 meissner@suse.de
- mark desktop file as needing kdesu root wrapper. bnc#550613
* Sun Feb 24 2008 crrodriguez@suse.de
-  use find_lang macro
-  link "as-needed" to eliminate a large amount of unused direct dependencies
* Thu Jul 26 2007 prusnak@suse.cz
- changed libpcap to libpcap-devel in BuildRequires
* Tue Oct 17 2006 meissner@suse.de
- etherape 0.9.7
  - bugfixes
* Tue Jun 27 2006 meissner@suse.de
- network traffic analysis and display ether-ape 0.9.6.
